clean up code
diff --git a/TestON/tests/SdnIpTest/SdnIpTest.py b/TestON/tests/SdnIpTest/SdnIpTest.py
index 7b18558..cf51848 100644
--- a/TestON/tests/SdnIpTest/SdnIpTest.py
+++ b/TestON/tests/SdnIpTest/SdnIpTest.py
@@ -1,18 +1,12 @@
 
 # Testing the basic functionality of SDN-IP
 class SdnIpTest:
 
     def __init__( self ):
         self.default = ''
-        global git_branch
-        
-    def CASE101( self, main ):
-        git_branch = main.params[ 'GIT' ][ 'branch1' ]
-    def CASE102( self, main ):
-        git_branch = main.params[ 'GIT' ][ 'branch2' ]
-    # Setup ONOS
+   
+    # This case is to setup ONOS
     def CASE100( self, main ):
-        import time
         """
            CASE100 is to compile ONOS and push it to the test machines
            Startup sequence:
@@ -26,26 +20,22 @@
         """
         main.case( "Setting up test environment" )
 
-        PULLCODE = False
-        #if main.params[ 'Git' ] == 'True':
-        #    PULLCODE = True
         cellName = main.params[ 'ENV' ][ 'cellName' ]
         ONOS1Ip = main.params[ 'CTRL' ][ 'ip1' ]
 
         main.step( "Applying cell variable to environment" )
         cellResult = main.ONOSbench.setCell( cellName )
         verifyResult = main.ONOSbench.verifyCell()
- 
+
         main.log.report( "Uninstalling ONOS" )
         main.ONOSbench.onosUninstall( ONOS1Ip )
 
         cleanInstallResult = main.TRUE
         gitPullResult = main.TRUE
- 
+
         main.step( "Git pull" )
-        #main.ONOSbench.gitCheckout( git_branch )
         gitPullResult = main.ONOSbench.gitPull()
-  
+
         main.step( "Using mvn clean & install" )
         cleanInstallResult = main.TRUE
         if gitPullResult == main.TRUE:
@@ -55,8 +45,8 @@
                             "clean install" )
         main.ONOSbench.getVersion( report=True )
   
-        cellResult = main.ONOSbench.setCell( cellName )
-        verifyResult = main.ONOSbench.verifyCell()
+        #cellResult = main.ONOSbench.setCell( cellName )
+        #verifyResult = main.ONOSbench.verifyCell()
         main.step( "Creating ONOS package" )
         packageResult = main.ONOSbench.onosPackage()
   
@@ -80,8 +70,8 @@
                         onos1Isup and cliResult )
   
         utilities.assert_equals( expect=main.TRUE, actual=case1Result,
-                                 onpass="Test startup successful",
-                                 onfail="Test startup NOT successful" )
+                                 onpass="ONOS startup successful",
+                                 onfail="ONOS startup NOT successful" )
   
         if case1Result == main.FALSE:
             main.cleanup()
@@ -102,12 +92,10 @@
         import time
         import json
         from operator import eq
-        # from datetime import datetime
         from time import localtime, strftime
 
-        main.case("The test case is to help to setup the TestON environment \
-            and test new drivers" )
-        # SDNIPJSONFILEPATH = "../tests/SdnIpTest/sdnip.json"
+        main.case("This case is to testing the functionality of SDN-IP with \
+        single ONOS instance" )
         SDNIPJSONFILEPATH = \
             "/home/admin/ONOS/tools/package/config/sdnip.json"
         # all expected routes for all BGP peers
@@ -147,33 +135,6 @@
 
         routeIntentsExpected = routeIntentsExpectedHost3 + \
             routeIntentsExpectedHost4 + routeIntentsExpectedHost5
-
-        #####
-#         cellName = main.params[ 'ENV' ][ 'cellName' ]
-#         ONOS1Ip = main.params[ 'CTRL' ][ 'ip1' ]
-#         main.step( "Set cell for ONOS-cli environment" )
-#         main.ONOScli.setCell( cellName )
-#         verifyResult = main.ONOSbench.verifyCell()
-# 
-#         main.log.report( "Removing raft logs" )
-#         main.ONOSbench.onosRemoveRaftLogs()
-#         main.log.report( "Uninstalling ONOS" )
-#         main.ONOSbench.onosUninstall( ONOS1Ip )
-# 
-#         main.step( "Installing ONOS package" )
-#         onos1InstallResult = main.ONOSbench.onosInstall(
-#             options="-f", node=ONOS1Ip )
-# 
-#         main.step( "Checking if ONOS is up yet" )
-#         time.sleep( 150 )
-#         onos1Isup = main.ONOSbench.isup( ONOS1Ip )
-#         if not onos1Isup:
-#             main.log.report( "ONOS1 didn't start!" )
-# 
-#         main.step( "Start ONOS-cli" )
-# 
-#         main.ONOScli.startOnosCli( ONOS1Ip )
-        #####
         
         main.step( "Get devices in the network" )
         listResult = main.ONOScli.devices( jsonFormat=False )
@@ -259,7 +220,7 @@
 
         main.step( "Check MultiPointToSinglePointIntent intents installed" )
         # routeIntentsExpected are generated when generating routes
-        # get rpoute intents from ONOS CLI
+        # get route intents from ONOS CLI
         routeIntentsActual = \
             main.QuaggaCliHost3.extractActualRouteIntents(
                 getIntentsResult )
@@ -313,7 +274,7 @@
                 "***PointToPointIntent Intents in SDN-IP are wrong!***" )
 
         #============================= Ping Test ========================
         # wait until all MultiPointToSinglePoint
         time.sleep( 20 )
         pingTestScript = "~/SDNIP/test-tools/CASE4-ping-as2host.sh"
         pingTestResultsFile = \
@@ -376,22 +337,20 @@
         time.sleep( 20 )
         pingTestScript = "~/SDNIP/test-tools/CASE4-ping-as2host.sh"
         pingTestResultsFile = \
-        "~/SDNIP/SdnIpIntentDemo/log/CASE4-ping-results-after-delete-routes-" \
+        "~/SDNIP/SdnIpIntentDemo/log/CASE4-ping-results-after-delete-routes-"\
             + strftime( "%Y-%m-%d_%H:%M:%S", localtime() ) + ".txt"
         pingTestResults = main.QuaggaCliHost.pingTest(
             "1.168.30.100", pingTestScript, pingTestResultsFile )
         main.log.info( pingTestResults )
         time.sleep( 100 )
 
-        # main.step( "Test whether Mininet is started" )
-        # main.Mininet2.handle.sendline( "xterm host1" )
-        # main.Mininet2.handle.expect( "mininet>" )
 
     def CASE3( self, main ):
         """
         Test the SDN-IP functionality
         allRoutesExpected: all expected routes for all BGP peers
-        routeIntentsExpected: all expected MultiPointToSinglePointIntent intents
+        routeIntentsExpected: all expected MultiPointToSinglePointIntent \
+        intents
         bgpIntentsExpected: expected PointToPointIntent intents
         allRoutesActual: all routes from ONOS LCI
         routeIntentsActual: actual MultiPointToSinglePointIntent intents from \
@@ -1,18 +1,12 @@
 
-# Testing the basic functionality of SDN-IP
+# Testing the functionality of SDN-IP with single ONOS instance
 class SdnIpTest:
 
@@ -313,7 +274,7 @@
 
         #============================= Ping Test ========================
-        # wait until all MultiPointToSinglePoint
+        # Wait until all MultiPointToSinglePoint intents are in system
         time.sleep( 20 )
         pingTestScript = "~/SDNIP/test-tools/CASE4-ping-as2host.sh"